import Alpaca from '@alpacahq/alpaca-trade-api';
import { QuoteProvider, Quote } from '../interface/quote';

/**
 * Provides quotes using the Alpaca API.
 */
export class AlpacaQuoteProvider implements QuoteProvider {
    /**
     * The Alpaca API client.
     */
    readonly alpaca: Alpaca;

    /**
     * Fetches a quote for the given stock symbol.
     * @param symbol The stock symbol to fetch the quote for.
     * @returns A Promise that resolves to a Quote object.
     */
    readonly fetchQuote = (symbol: string): Promise<Quote> => {
        return this.alpaca.getLatestQuote(symbol).then((quote) => {
            return new Quote(
                quote.Symbol,
                quote.AskPrice,
                quote.AskSize,
                quote.BidPrice,
                quote.BidSize,
                new Date(Date.parse(quote.Timestamp))
            );
        }).catch((err) => {
            return err;
        });
    };

    /**
     * Creates a new AlpacaQuoteProvider instance.
     * @constructor
     * @param {Alpaca} alpaca - The Alpaca API client.
     */
    constructor(alpaca: Alpaca) {
        this.alpaca = alpaca;
    }
}
